//
//  WordTableDataSource.m
//  BookWorm
//
//  Created by Curtis Jones on 2007.11.19.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import "WordTableDataSource.h"


@implementation WordTableDataSource

- (id)init
{
	self = [super init];
	
	if (self) {
		mWords = [[NSMutableArray alloc] initWithCapacity:100];
	}
	
	return self;
}

- (void)dealloc
{
	[mWords release];
	
	[super dealloc];
}

- (void)addWord:(BWWord *)aWord
{
	if (aWord == nil)
		return;
	
	@synchronized (mWords) { [mWords addObject:aWord]; }
}

- (void)deleteAll
{
	@synchronized (mWords) { [mWords removeAllObjects]; }
}

- (int)count
{
	return [mWords count];
}

- (BWWord *)wordAtIndex:(int)index
{
	BWWord * word = nil;
	
	@synchronized (mWords)
	{
		if ([mWords count] > index)
			word = [mWords objectAtIndex:index];
	}
	
	return word;
}





///////////////////////////////////////////////////////////////////////////////

#pragma mark -
#pragma mark data source functions (get)





- (int)numberOfRowsInTableView:(NSTableView *)aTableView
{
	return [self count];
}

- (id)tableView:(NSTableView *)aTableView objectValueForTableColumn:(NSTableColumn *)aTableColumn row:(int)rowIndex
{
	NSString * column = [aTableColumn identifier];
	BWWord * word = [mWords objectAtIndex:rowIndex];
	
	// word
	if ([column isEqualToString:@"word"])
		return word.word;
	
	// points
	else if ([column isEqualToString:@"points"])
		return word.valu;
	
	// path
	else if ([column isEqualToString:@"path"])
		return word.path;
	
	// leng
	else if ([column isEqualToString:@"leng"])
		return word.leng;
	
	else
		NSLog(@"%s.. unsupported column, '%@'", __PRETTY_FUNCTION__, column);
	
	return column;
}





///////////////////////////////////////////////////////////////////////////////

#pragma mark -
#pragma mark data source functions (sorting)





- (void)tableView:(NSTableView *)tableView sortDescriptorsDidChange:(NSArray *)oldDescriptors
{
	[mWords sortUsingDescriptors:[tableView sortDescriptors]];
	[tableView reloadData];
}

@end
